﻿using UnityEngine;
using System.Collections;

public class AlienBehaviour : MonoBehaviour {
	// Explosion to instantiate upon death
	public SpriteRenderer bigExplosion;

	private float _speed = 1.0f;
	private bool _shouldBeDestroyed = false;
	private bool _destroyQuietly = false;
	private bool _shouldDestroyPlayer = false;

	void Start() {
		// Randomize the layer this alien starts on
		gameObject.renderer.sortingOrder = Random.Range(-100, 100);
	}

	/*
	 * Randomizes the speed of this alien between the min and max (inclusive)
	 */
	public void SetRandomSpeed(float min, float max) {
		_speed = Random.Range (min, max);
	}

	// Update is called once per frame
	public void UpdateEnemy(MainGameControllerBehaviour.GameState currentState) {
		if(currentState == MainGameControllerBehaviour.GameState.Paused) {
			// Do not move
			rigidbody2D.velocity = new Vector2(0.0f, 0.0f);
		} else if(currentState == MainGameControllerBehaviour.GameState.GameOver) {
			// Speed to bottom of screen as animation
			rigidbody2D.velocity = new Vector2(0.0f, _speed - 5f);
		} else {
			// Move down normally
			rigidbody2D.velocity = new Vector2(0.0f, _speed * -1f);
		}
	}

	void OnCollisionEnter2D(Collision2D colInfo) {
		if (colInfo.collider.tag == "Player") {
			_shouldDestroyPlayer = true;
			_shouldBeDestroyed = true;
			// Destroy the player
			//colInfo.gameObject.SendMessage ("DestroyShip");
		} else if (colInfo.collider.tag == "Bullet") {
			// Destroy the bullet and die
			colInfo.gameObject.SendMessage ("SetToDestroy");
			_shouldBeDestroyed = true;
			ScoreManagerBehaviour.AddToScore(10);
		} else if (colInfo.collider.tag == "BottomWall") {
			// Destroy self quietly (no explosion)
			_shouldBeDestroyed = true;
			_shouldDestroyPlayer = true;
			_destroyQuietly = true;
		}
	}

	/*
	 * Returns whether this object should be destroyed
	 */
	public bool ShouldBeDestroyed 
	{
		get { return _shouldBeDestroyed; }
	}

	/*
	 * Returns whether this object should destroy the player (game over)
	 */
	public bool ShouldDestroyPlayer
	{
		get { return _shouldDestroyPlayer; }
	}

	/*
	 * Destroys this ship
	 */
	public void DestroyShip(){
		if(!_destroyQuietly) {
			SpriteRenderer explosionInstance = (SpriteRenderer)Instantiate(bigExplosion, transform.position, transform.rotation);
		}
		Destroy(gameObject);
	}
}
