﻿using UnityEngine;
using System.Collections;

public class PlayerController : MonoBehaviour {

	public MainGameControllerBehaviour MainController;
	public BulletFactory BulletFactoryInstance;
	
	public SpriteRenderer bigExplosionPrefab;

	// Game control keys
	public KeyCode moveLeft;
	public KeyCode moveRight;
	public KeyCode pauseGame;
	public KeyCode shootButton;

	public GameObject flameChild;
	public AudioSource ShootSound;

	private float _speed = 10;

	private Vector2 _finalCutsceneY;
	private bool _isPlayingIntro = false;
	private static float _introVelocityY = 4f;
	private float _currentYVelocity;

	private float _reloadTimer = 0f;
	private static float _reloadTime = 0.3f;

	void Start() {
		_reloadTimer = _reloadTime;
		_finalCutsceneY = new Vector2(0.0f, MainController.mainCam.ScreenToWorldPoint(new Vector3(0f, 175f, 0f)).y);
	}

	// Update is called once per frame
	public void UpdatePlayerControls (MainGameControllerBehaviour.GameState currentState) {
		if(_isPlayingIntro) {
			rigidbody2D.velocity = new Vector2(0f, _introVelocityY);

			// Determine if we should stop the intro cutscene
			if (transform.position.y >= _finalCutsceneY.y) {
				_isPlayingIntro = false;
				transform.position = new Vector2(transform.position.x, _finalCutsceneY.y);
				_currentYVelocity = 0f;
				flameChild.SetActive(false);
			}
		}

		// Process controls while in game
		if(currentState == MainGameControllerBehaviour.GameState.InGame) {
			if(Input.GetKey(moveRight)) {
				rigidbody2D.velocity = new Vector2(_speed, _currentYVelocity);
			} else if(Input.GetKey(moveLeft)) {
				rigidbody2D.velocity = new Vector2(_speed * -1, _currentYVelocity);
			} else {
				if (!_isPlayingIntro) {
					rigidbody2D.velocity = new Vector2(0.0f, 0.0f);
				}
			}

			// Only shoot after reload time is passed
			if(Input.GetKeyDown(shootButton) && _reloadTimer >= _reloadTime) {
				ShootSound.audio.Play();
				BulletFactoryInstance.GenerateBullet(new Vector2(transform.position.x, transform.position.y), transform.rotation);
				_reloadTimer = 0f;
			}

			if(_reloadTimer < _reloadTime) {
				_reloadTimer += Time.deltaTime;
			}
		} else {
			rigidbody2D.velocity = new Vector2(0.0f, 0.0f);
		}

		// Allow pause/unpause at any time
		if(Input.GetKeyDown(pauseGame) && !MainController.IsStartKeyDown) {
			MainController.PushGameState(MainGameControllerBehaviour.GameState.Paused);
		}
	}

	/*
	 * Displays an explosion and hides the game object
	 */
	public void DestroyShip() {
		SpriteRenderer bigExplosion = (SpriteRenderer)Instantiate(bigExplosionPrefab, transform.position, transform.rotation);
		gameObject.SetActive(false);
		MainController.PushGameState (MainGameControllerBehaviour.GameState.GameOver);
	}

	/*
	 * 'Plays' the intro animation
	 */
	public void PlayIntroCutscene() {
		_isPlayingIntro = true;

		Vector2 startPos = new Vector2(0f, MainController.mainCam.ScreenToWorldPoint(new Vector3(0f, 0f, 0f)).y - 1.75f);
		transform.position = startPos;

		_currentYVelocity = _introVelocityY;

		gameObject.SetActive(true);
		flameChild.SetActive(true);
	}
}
