﻿using UnityEngine;
using System.Collections;
using System.Collections.Generic;

public class StarLayerBehaviour : MonoBehaviour {

	public float Speed = 0f;
	public GameObject TopImage;
	public GameObject BottomImage;

	// Image components
	private SpriteRenderer _topRenderer;
	private Rigidbody2D _topBody;
	private SpriteRenderer _bottomRenderer;
	private Rigidbody2D _bottomBody;

	private GameObject _removalZone;

	// Use this for initialization
	void Start () {
		// Get image components for later user
		_topBody = TopImage.rigidbody2D;
		_topRenderer = (SpriteRenderer)TopImage.GetComponent ("SpriteRenderer");
		
		_bottomBody = BottomImage.rigidbody2D;
		_bottomRenderer = (SpriteRenderer)BottomImage.GetComponent ("SpriteRenderer");

		// Set top image about current bottom location
		float foregroundY = BottomImage.transform.position.y 
			+ _bottomRenderer.bounds.size.y;
		
		TopImage.transform.position = new Vector2 (BottomImage.transform.position.x, foregroundY);

		// Get the removal zone object
		_removalZone = GameObject.Find ("BottomWall");
	}
	
	// Update is called once per frame
	public void UpdateLayer (MainGameControllerBehaviour.GameState currentState) {
		if (currentState == MainGameControllerBehaviour.GameState.Paused) {
			_topBody.velocity = Vector2.zero;
			_bottomBody.velocity = Vector2.zero;
		} else {
			_topBody.velocity = new Vector2 (0f, Speed * -1);
			_bottomBody.velocity = new Vector2 (0f, Speed * -1);
			
			ResetImage();
		}
	}

	/*
	 * Take an image that is passed the removal zone and place it above the other image
	 */
	private void ResetImage() {
		// Reset bottom image
		if (BottomImage.transform.position.y + _bottomRenderer.bounds.extents.y < _removalZone.transform.position.y) {
			float foregroundY = _topBody.transform.position.y 
				+ _topRenderer.bounds.size.y;
			
			BottomImage.transform.position = new Vector2 (TopImage.transform.position.x, foregroundY);
		}

		// Reset top image
		if (TopImage.transform.position.y + _topRenderer.sprite.bounds.max.y < _removalZone.transform.position.y) {
			float foregroundY = _bottomBody.transform.position.y 
				+ _bottomRenderer.bounds.size.y;
			
			TopImage.transform.position = new Vector2 (BottomImage.transform.position.x, foregroundY);
		}
	}
}
